from prof_checker import output_results

def test_output_predict():
    test_strings = ["Hello World!", "Fuck U"]
    assert(output_results(test_strings, [("test.py", 1), ("test.py", 2)], None) == -1)


def test_output_probability():
    test_strings = ["Hello World!", "Fuck U"]
    assert(output_results(test_strings, [("test.py", 1), ("test.py", 2)], 0.5) == -1)



import click
from enum import Enum
from typing import List, Tuple, Optional
from functools import partial
from tokenize import STRING, tokenize, COMMENT

__version__ = "1.0.2"

out = partial(click.secho, bold=True, err=True)


def fetch_strings(src: str, strings_found: List[str], infos: List[Tuple[str, int]]) -> None:
    with open(src, "rb") as f:
        for tok in tokenize(f.readline):
            if tok.type == STRING:
                current_string = tok.string
                if current_string[:3] == '"""':
                    current_string = current_string[3:-3]
                else:
                    current_string = current_string[1:-1]
                current_string = current_string.strip("\n")
                current_string = current_string.strip(" ")
                strings_found.append(current_string)
                infos.append((src, tok.start[0]))

            if tok.type == COMMENT:
                strings_found.append(tok.string)
                infos.append((src, tok.start[0]))


def output_results(
    strings: List[str], infos: List[Tuple[str, int]], probability: Optional[int]
) -> int:
    assert len(strings) == len(infos)
    if probability is None or not 0 < probability < 1:
        from profanity_check import predict  # type: ignore

        predictions = predict(strings)
        probability = 0
    else:
        from profanity_check import predict_prob  # type: ignore

        predictions = predict_prob(strings)

    results = list(filter(lambda x: predictions[x[0]] > probability, enumerate(infos)))

    if results:
        click.secho("Probable profanities found: ", err=True)
        for result in results:
            out(
                "\tIn {} on line {}: {}".format(
                    result[1][0], result[1][1], strings[result[0]]
                )
            )
        return -1

    click.secho("No profanities found, yaay!")
    return 0


@click.command(context_settings=dict(help_option_names=["-h", "--help"]))
@click.option(
    "-P",
    "--probability",
    type=float,
    help="Instead of prediction, use probability threshold",
)
@click.version_option(version=__version__)
@click.argument(
    "src",
    nargs=-1,
    type=click.Path(
        exists=True, file_okay=True, dir_okay=True, readable=True, allow_dash=True
    ),
    is_eager=True,
)
def main(probability, src):
    """ Profanity checker wrapper for python scripts/services """
    if not src:
        out("No paths given, nothing to do...")
        return

    strings_found = []
    infos = []
    for fl in set(src):
        fetch_strings(fl, strings_found, infos)

    output_results(strings_found, infos, probability)


if __name__ == "__main__":
    main()



import ast
import re
from setuptools import setup, find_packages


with open("README.md", "r") as fh:
    long_description = fh.read()


with open("prof_checker.py", "r") as fh:
    _version_re = re.compile(r"__version__\s+=\s+(?P<version>.*)")
    match = _version_re.search(fh.read())
    version = match.group("version") if match is not None else '"unknown"'
    version = str(ast.literal_eval(version))


setup(
    name="prof-checker",
    version=version,
    author="Tornike Gogniashvili",
    author_email="t.gogniashvili@gmail.com",
    description="Wrapper for profanity checker that can work on python services/scripts, similar to linters (e.g. pylint)",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/ozychhi/prof-checker",
    packages=find_packages(),
    install_requires=["profanity-check", "click>=6.5"],
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Natural Language :: English",
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    extras_require={
        "dev": ["pytest", "tox", "black"],
    },
    py_modules=["prof_checker"],
    entry_points={"console_scripts": ["prof_checker=prof_checker:main"]},
)
